pub struct CurrentSlidePanel { /* private fields */ }Expand description
Manages the current slide display in the presenter console.
Implementations
Sourceimpl CurrentSlidePanel
impl CurrentSlidePanel
pub fn new() -> Self
Sourcepub fn update(&mut self, ctx: &Context, page: &RenderedPage, page_index: usize)
pub fn update(&mut self, ctx: &Context, page: &RenderedPage, page_index: usize)
Update the texture data when the page changes.
Sourcepub fn show(&mut self, ui: &mut Ui, area: Rect) -> (Response, Rect)
pub fn show(&mut self, ui: &mut Ui, area: Rect) -> (Response, Rect)
Render the current slide in the given area. Returns the response and the image rect for mouse handling.
Sourcepub fn show_with_sense(
&mut self,
ui: &mut Ui,
area: Rect,
sense: Sense,
) -> (Response, Rect)
pub fn show_with_sense( &mut self, ui: &mut Ui, area: Rect, sense: Sense, ) -> (Response, Rect)
Render the current slide with a caller-provided interaction sense. Returns the response and the image rect for mouse handling.
Sourcepub fn image_rect(&self) -> Rect
pub fn image_rect(&self) -> Rect
The image rect from the most recent render.